dupin.data.freud
--------------------------

.. rubric:: Overview

.. py:currentmodule:: dupin.data.freud

.. autosummary::
    :nosignatures:

    FreudDescriptor

.. rubric:: Details

.. automodule:: dupin.data.freud
    :synopsis: Helper classes/functions for working with freud in ``dupin``.
    :members: FreudDescriptor
